@@ -5,7 +5,9 @@
 
 use crate::Doc;
 
+pub mod rust_markdown_tag;
 pub mod rust_remove_comments;
+mod utils;
 
 pub trait DocTransform {
     type E;
